@@ -11,10 +11,14 @@ names(survd) <- c("time","status","x1","x2","x3")
 library(survival)
 coxph.fit <- coxph(Surv(time,status)~x1+x2+x3,data=survd)
 
-### Calculate CPE and CPE.SE
 library(CPE)
+
+### Calculate CPE and CPE.SE
 phcpe(coxph.fit)
 
+### Calculate CPE only (needs much less time)
+phcpe(coxph.fit, CPE.SE=FALSE)
+
 #*** For unknown reason, 'coxph.fit' may need to be removed before running cph()***
 rm(coxph.fit)
 
@@ -23,3 +27,7 @@ cph.fit <- cph(Surv(time, status)~x1+x2+x3, data=survd)
 
 ### Calculate CPE and CPE.SE
 phcpe(cph.fit)
+
+### Calculate CPE only (needs much less time)
+phcpe(cph.fit, CPE.SE=FALSE)
+
